@@ -4,7 +4,7 @@ from ts_t1_validator.models.enums.cap_type import CapTypeEnum
 
 
 class CapTypeSwitchPutRule(ValidationRule):
-    def __init__(self, cap_type_new, cap_type_old, cap_fields={}):
+    def __init__(self, cap_type_new, cap_type_old, cap_fields=dict):
 
         assert type(cap_type_new) is CapTypeEnum, "cap_type_new should have type of CapTypeEnum"
         assert type(cap_type_old) is CapTypeEnum, "cap_type_new should have type of CapTypeEnum"
