@@ -19,6 +19,7 @@ from .. import T1Service
 from ..models.dto.campaign import CampaignDTO
 from ..models.dto.strategy import StrategyDTO
 from ..models.enums.goal_type import GoalTypeEnum
+from ..models.enums.impression_pacing_type import ImpressionPacingTypeEnum
 
 
 class StrategyPostValidator(AbstractValidator):
@@ -119,10 +120,11 @@ class StrategyPostValidator(AbstractValidator):
             amount=dto.pacing_amount,
             amount_field="pacing_amount"))
 
-        self.rules.append(T1AmountRanges(
-            type_ranges=StrategyImpressionRanges,
-            amount=dto.impression_pacing_amount,
-            amount_field="impression_pacing_amount"))
+        if dto.impression_pacing_type is not ImpressionPacingTypeEnum.UNDEFINED:
+            self.rules.append(T1AmountRanges(
+                type_ranges=StrategyImpressionRanges,
+                amount=dto.impression_pacing_amount,
+                amount_field="impression_pacing_amount"))
 
         self.rules.append(T1AmountRanges(
             type_ranges=StrategyFrequencyRanges,
